# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.x     | :white_check_mark: |
| 1.x     | :x:                |

## Reporting a Vulnerability

To report any bug, please open an issue in our [issue tracker](https://github.com/codrsquad/pickley/issues).
